# Introduction

`psymple` is a package designed for general complex systems modelling. A complex system is a dynamic system whose interconnectivity produces non-trivial or unexpected behaviour. Examples of complex systems exist everywhere, from ecological systems, chemical reactions, economic systems, astronomy and even social networks.

The [sections below](#where-to-start) give a wide introduction to the structure of `psymple`, why it exists, how to use it, and how to get involved.

## Installation

`psymple` is a Python package currently supporting versions `3.10` and higher. 

The latest version of `psymple` is available on [PyPI](https://pypi.org/project/psymple/) and can be installed with `pip`.

```
pip install psymple
```

`psymple` includes automated tests. More information can be found on the [testing](./development/testing_psymple.md) page.

## Where to start

For most new users, going through the following resources in the suggested order will provide a good introduction to `psymple`. 

<div class="grid cards" markdown>


-   :material-roman-numeral-1:{ .lg .middle } __Why psymple exists__

    ---

    Find out about the purpose and design principles of `psymple`.

    [:octicons-arrow-right-24: Read more](./overview/introduction.md)

-   :material-roman-numeral-2:{ .lg .middle } __Modelling in psymple__

    ---

    Learn how to capture functions and differential equations in `psymple`, and combine these into complex models.

    [:octicons-arrow-right-24: Start modelling](./components/functional_ported_objects.md)

-   :material-roman-numeral-3:{ .lg .middle } __Simulating models__

    ---

    Understand how to create and run simulations for `psymple` models.

    [:octicons-arrow-right-24: Run simulations](./user_guide/system.md)

-   :material-roman-numeral-4:{ .lg .middle } __Tutorials__

    ---

    Work through full examples of implementing, parametrising and simulating models.

    [:octicons-arrow-right-24: See more](./examples/index.md)

-   :material-roman-numeral-5:{ .lg .middle } __The mathematics__

    ---

    Learn more about the mathematical structures underneath psymple which tie everything together.

    [:octicons-arrow-right-24: See the maths](./mathematics/ported_objects.md)

-   :material-roman-numeral-6:{ .lg .middle } __Get involved__

    ---

    Find out how you can get involved in the community by using or developing `psymple`.

    [:octicons-arrow-right-24: Get involved](./development/development.md)

</div>